@@ -136,7 +136,7 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <location filename="mainwindow.ui" line="590"/>
-        <location filename="mainwindow.cpp" line="270"/>
+        <location filename="mainwindow.cpp" line="275"/>
         <source>About</source>
         <translation>Informazioni</translation>
     </message>
@@ -162,8 +162,9 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <location filename="mainwindow.ui" line="616"/>
-        <source>RestoreDefaultList</source>
-        <translation>Ripristina Lista di default</translation>
+        <source>AddDefaultList</source>
+        <oldsource>RestoreDefaultList</oldsource>
+        <translation>Aggiungi Lista di default</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="621"/>
@@ -226,7 +227,7 @@ p, li { white-space: pre-wrap; }
         <translation>Lista preferiti</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="446"/>
+        <location filename="mainwindow.cpp" line="451"/>
         <source>DoNotFilter</source>
         <translation>Nessun filtro</translation>
     </message>
@@ -236,37 +237,37 @@ p, li { white-space: pre-wrap; }
         <translation>Impostazioni</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="87"/>
+        <location filename="mainwindow.cpp" line="92"/>
         <source>&lt;b&gt;Playing:&lt;/b&gt; %1</source>
         <translation>&lt;b&gt;In esecuzione:&lt;/b&gt; %1</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="113"/>
+        <location filename="mainwindow.cpp" line="118"/>
         <source>&lt;b&gt;Genre:&lt;/b&gt; %1</source>
         <translation>&lt;b&gt;Genere:&lt;/b&gt; %1</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="121"/>
+        <location filename="mainwindow.cpp" line="126"/>
         <source>&lt;b&gt;Bitrate:&lt;/b&gt; %1</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="129"/>
+        <location filename="mainwindow.cpp" line="134"/>
         <source>&lt;b&gt;Location:&lt;/b&gt; %1</source>
         <translation>&lt;b&gt;Posizione:&lt;/b&gt; %1</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="137"/>
+        <location filename="mainwindow.cpp" line="142"/>
         <source>&lt;b&gt;Audio codec:&lt;/b&gt; %1</source>
         <translation>&lt;b&gt;Codec audio:&lt;/b&gt; %1</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="187"/>
+        <location filename="mainwindow.cpp" line="192"/>
         <source>No lyric found</source>
         <translation>Nessun testo trovato</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="206"/>
+        <location filename="mainwindow.cpp" line="211"/>
         <source>Loading lyrics...</source>
         <translation>Sto cercando il testo...</translation>
     </message>
@@ -280,81 +281,79 @@ p, li { white-space: pre-wrap; }
         <translation type="obsolete">&lt;h2&gt;Internet Radio Player 0.0.7&lt;/h2&gt;&lt;p&gt;&lt;p&gt;Scritto da Giovanni Grammatico (ggiovanni88@yahoo.it)&lt;p&gt;&lt;a href=&quot;http://code-tinkering.blogspot.com/&quot;&gt;Il mio blog personale.&lt;/a&gt; &lt;a href=&quot;mailto:ggiovanni88@yahoo.it&quot;&gt;Mandami una email.&lt;/a&gt; {2&gt;?} {0.0.8&lt;?} {2&gt;?} {88@?} {88@?}</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="271"/>
+        <location filename="mainwindow.cpp" line="276"/>
         <source>&lt;h2&gt;Internet Radio Player %1&lt;/h2&gt;&lt;p&gt;&lt;p&gt;Written by Giovanni Grammatico (ggiovanni88@yahoo.it)&lt;p&gt;&lt;a href=&quot;http://code-tinkering.blogspot.com/&quot;&gt;My personal blog.&lt;/a&gt; &lt;a href=&quot;mailto:ggiovanni88@yahoo.it&quot;&gt;Send me an email.&lt;/a&gt;</source>
         <translation>&lt;h2&gt;Internet Radio Player %1&lt;/h2&gt;&lt;p&gt;&lt;p&gt;Scritto da Giovanni Grammatico (ggiovanni88@yahoo.it)&lt;p&gt;&lt;a href=&quot;http://code-tinkering.blogspot.com/&quot;&gt;Il mio blog personale.&lt;/a&gt; &lt;a href=&quot;mailto:ggiovanni88@yahoo.it&quot;&gt;Mandami una email.&lt;/a&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="282"/>
-        <location filename="mainwindow.cpp" line="284"/>
-        <location filename="mainwindow.cpp" line="286"/>
-        <location filename="mainwindow.cpp" line="288"/>
+        <location filename="mainwindow.cpp" line="287"/>
+        <location filename="mainwindow.cpp" line="289"/>
+        <location filename="mainwindow.cpp" line="291"/>
+        <location filename="mainwindow.cpp" line="293"/>
         <source>New Station</source>
         <translation>Nuova stazione</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="282"/>
-        <location filename="mainwindow.cpp" line="310"/>
+        <location filename="mainwindow.cpp" line="287"/>
+        <location filename="mainwindow.cpp" line="315"/>
         <source>Insert Name: </source>
         <translation>Inserisci nome:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="284"/>
-        <location filename="mainwindow.cpp" line="312"/>
+        <location filename="mainwindow.cpp" line="289"/>
+        <location filename="mainwindow.cpp" line="317"/>
         <source>Insert Url: </source>
         <translation>Inserisci Indirizzo:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="286"/>
-        <location filename="mainwindow.cpp" line="314"/>
+        <location filename="mainwindow.cpp" line="291"/>
+        <location filename="mainwindow.cpp" line="319"/>
         <source>Insert Genre: </source>
         <translation>Inserisci Genere:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="288"/>
-        <location filename="mainwindow.cpp" line="316"/>
+        <location filename="mainwindow.cpp" line="293"/>
+        <location filename="mainwindow.cpp" line="321"/>
         <source>Insert Country: </source>
         <translation>Inserisci il Paese:</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="310"/>
-        <location filename="mainwindow.cpp" line="312"/>
-        <location filename="mainwindow.cpp" line="314"/>
-        <location filename="mainwindow.cpp" line="316"/>
+        <location filename="mainwindow.cpp" line="315"/>
+        <location filename="mainwindow.cpp" line="317"/>
+        <location filename="mainwindow.cpp" line="319"/>
+        <location filename="mainwindow.cpp" line="321"/>
         <source>Edit Station</source>
         <translation>Modifica la stazione</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="334"/>
-        <location filename="mainwindow.cpp" line="467"/>
-        <location filename="mainwindow.cpp" line="483"/>
+        <location filename="mainwindow.cpp" line="339"/>
+        <location filename="mainwindow.cpp" line="472"/>
         <source>Internet Radio Widget</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="335"/>
+        <location filename="mainwindow.cpp" line="340"/>
         <source>Do you really want to delete the chosen station?</source>
         <translation>Vuoi veramente cancellare la stazione evidenziata?</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="447"/>
+        <location filename="mainwindow.cpp" line="452"/>
         <source>FilterList</source>
         <translation>Filtra lista</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="448"/>
+        <location filename="mainwindow.cpp" line="453"/>
         <source>ManageFavourites</source>
         <translation>Gestisci preferiti</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="468"/>
+        <location filename="mainwindow.cpp" line="473"/>
         <source>This will clear your stations list.&lt;p&gt;Do you really want to continue?</source>
         <translation>Questo azzererà la tua lista stazioni.&lt;p&gt;Vuoi veramente continuare?</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="484"/>
         <source>This will clear your stations list and restore default one.&lt;p&gt;Do you really want to continue?</source>
-        <translation>Questo azzererà la tua lista stazioni e ripristinerà quella di default-.&lt;p&gt;Vuoi veramente continuare?</translation>
+        <translation type="obsolete">Questo azzererà la tua lista stazioni e ripristinerà quella di default-.&lt;p&gt;Vuoi veramente continuare?</translation>
     </message>
 </context>
 <context>
