@@ -3,7 +3,7 @@
 #include "radiostation.h"
 #include "texteditautoresizer.h"
 
-const QString appVersion = "1.0.6";
+const QString appVersion = "1.0.7";
 
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent), ui(new Ui::MainWindow), quitActionPressed(false), hideWhenClosing(false)
@@ -651,7 +651,7 @@ void MainWindow::closeEvent(QCloseEvent *event)
     else
     {
         //Hiding app
-        hide();
+        QMainWindow::hide();
         event->ignore();
     }
 }
@@ -809,7 +809,7 @@ void MainWindow::prev()
 
 void MainWindow::hide()
 {
-    hide();
+    QMainWindow::hide();
 }
 
 void MainWindow::quit()
